@@ -3,8 +3,7 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_AUTOHOST_H
 #define SPRINGLOBBY_HEADERGUARD_AUTOHOST_H
 
-//including this header is only really needed for time_t ..
-#include <wx/string.h>
+#include <time.h>
 #include <wx/arrstr.h>
 
 class IBattle;
