@@ -20,7 +20,6 @@
 #include "utils/conversion.h"
 #include "utils/uievents.h"
 #include "utils/battleevents.h"
-#include "utils/slpaths.h"
 #include "gui/uiutils.h"
 #include "settings.h"
 #include "useractions.h"
@@ -593,18 +592,6 @@ void Battle::StartHostedBattle()
 				if (UserExists(GetProxy()) && !GetUser(GetProxy()).Status().in_game) {
 					// DON'T set m_generating_script here, it will trick the script generating code to think we're the host
 					wxString hostscript = spring().WriteScriptTxt(*this);
-					try {
-						wxString path = TowxString(SlPaths::GetDataDir()) + _T("relayhost_script.txt");
-						if (!wxFile::Access(path, wxFile::write)) {
-							wxLogError(_T("Access denied to script.txt."));
-						}
-
-						wxFile f(path, wxFile::write);
-						f.Write(hostscript);
-						f.Close();
-
-					} catch (...) {
-					}
 					m_serv.SendScriptToProxy(STD_STRING(hostscript));
 				}
 			}
