@@ -4,7 +4,7 @@
 #include "Download.h"
 #include "Http/HttpDownloader.h"
 #include "Rapid/RapidDownloader.h"
-#include "Plasma/PlasmaDownloader.h"
+//#include "Plasma/PlasmaDownloader.h"
 #include "Util.h"
 #include "Logger.h"
 #include "Mirror.h"
@@ -13,7 +13,7 @@
 class IDownloader;
 
 IDownloader* IDownloader::httpdl=NULL;
-IDownloader* IDownloader::plasmadl=NULL;
+//IDownloader* IDownloader::plasmadl=NULL;
 IDownloader* IDownloader::rapiddl=NULL;
 
 void IDownloader::Initialize(IDownloadsObserver* observer)
@@ -26,8 +26,8 @@ void IDownloader::Shutdown()
 {
 	delete(httpdl);
 	httpdl = NULL;
-	delete(plasmadl);
-	plasmadl = NULL;
+//	delete(plasmadl);
+//	plasmadl = NULL;
 	delete(rapiddl);
 	rapiddl = NULL;
 	curl_global_cleanup();
@@ -45,12 +45,14 @@ IDownloader* IDownloader::GetRapidInstance()
 		rapiddl=new CRapidDownloader();
 	return rapiddl;
 }
+/*
 IDownloader* IDownloader::GetPlasmaInstance()
 {
 	if (plasmadl==NULL)
 		plasmadl=new CPlasmaDownloader();
 	return plasmadl;
 }
+*/
 
 bool IDownloader::download(std::list<IDownload*>& download, int max_parallel)
 {
