@@ -35,6 +35,7 @@
 #include "gui/wxtextctrlhist.h"
 #include "log.h"
 #include "utils/slconfig.h"
+#include "gui/hosting/votepanel.h"
 
 BEGIN_EVENT_TABLE(ChatPanel, wxPanel)
 
@@ -86,6 +87,7 @@ void ChatPanel::Init(const wxString& panelname)
 ChatPanel::ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist)
     : wxPanel(parent, -1)
     , m_show_nick_list(true)
+    , m_votePanel(0)
     , m_nicklist(0)
     , m_chat_tabs((SLNotebook*)parent)
     , m_channel(&chan)
@@ -108,6 +110,7 @@ ChatPanel::ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist)
 ChatPanel::ChatPanel(wxWindow* parent, const User& user, wxImageList* imaglist)
     : wxPanel(parent, -1)
     , m_show_nick_list(false)
+    , m_votePanel(0)
     , m_nicklist(0)
     , m_chat_tabs((SLNotebook*)parent)
     , m_channel(0)
@@ -130,6 +133,7 @@ ChatPanel::ChatPanel(wxWindow* parent, const User& user, wxImageList* imaglist)
 ChatPanel::ChatPanel(wxWindow* parent, IServer& serv, wxImageList* imaglist)
     : wxPanel(parent, -1)
     , m_show_nick_list(true)
+    , m_votePanel(0)
     , m_nicklist(0)
     , m_chat_tabs((SLNotebook*)parent)
     , m_channel(0)
@@ -152,6 +156,7 @@ ChatPanel::ChatPanel(wxWindow* parent, IServer& serv, wxImageList* imaglist)
 ChatPanel::ChatPanel(wxWindow* parent, IBattle* battle)
     : wxPanel(parent, -1)
     , m_show_nick_list(false)
+    , m_votePanel(0)
     , m_nicklist(0)
     , m_chat_tabs(0)
     , m_channel(0)
@@ -171,6 +176,7 @@ ChatPanel::ChatPanel(wxWindow* parent, IBattle* battle)
 ChatPanel::ChatPanel(wxWindow* parent)
     : wxPanel(parent, -1)
     , m_show_nick_list(false)
+    , m_votePanel(0)
     , m_nicklist(0)
     , m_chat_tabs(0)
     , m_channel(0)
@@ -228,16 +234,11 @@ void ChatPanel::CreateControls()
 		m_chat_panel = new wxPanel(m_splitter, -1);
 
 		m_nick_sizer = new wxBoxSizer(wxVERTICAL);
-		unsigned int numusers = 0;
-		if (m_type == CPT_Channel)
-			numusers = GetChannel()->GetNumUsers();
-		else if (m_type == CPT_Server && m_server)
-			numusers = m_server->GetNumUsers();
-		m_usercount_label = new wxStaticText(m_nick_panel, wxID_ANY, wxString::Format(_("%d users"), numusers));
+		m_usercount_label = new wxStaticText(m_nick_panel, wxID_ANY, wxEmptyString);
+		UpdateUserCountLabel();
 		CreatePopup(); //ensures m_popup_menu is constructed
 		//SL_GENERIC::UserMenu<ChatPanelMenu>* usermenu  = m_popup_menu->GetUserMenu();
-		assert(m_popup_menu->GetUserMenu());
-		m_nicklist = new NickListCtrl(m_nick_panel, true, m_popup_menu->GetUserMenu());
+		m_nicklist = new NickListCtrl(m_nick_panel, true, m_popup_menu);
 
 		// m_nick_filter = new wxComboBox( m_nick_panel, -1, _("Show all"), wxDefaultPosition, wxSize(80,CONTROL_HEIGHT), 0, 0, wxCB_READONLY );
 		// m_nick_filter->Disable();
@@ -586,6 +587,11 @@ bool ChatPanel::ContainsWordToHighlight(const wxString& message) const
 
 void ChatPanel::DidAction(const wxString& who, const wxString& action)
 {
+	//Handle vote events in chat by VotePanel
+	if (m_votePanel != NULL) {
+		m_votePanel->OnChatAction(who, action);
+	}
+
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
 	OutputLine(_T( " * " ) + who + _T( " " ) + action, sett().GetChatColorAction());
@@ -629,6 +635,12 @@ void ChatPanel::UnknownCommand(const wxString& command, const wxString& params)
 	OutputLine(_(" !! Command: \"") + command + _("\" params: \"") + params + _T( "\"." ), sett().GetChatColorError());
 }
 
+void ChatPanel::OutputError(const wxString& message)
+{
+	OutputLine(wxString::Format(_(" Error: %s"), message.c_str()), sett().GetChatColorError());
+}
+
+
 wxString ChatPanel::GetChatTypeStr() const
 {
 	if (m_type == CPT_Channel)
@@ -652,13 +664,8 @@ void ChatPanel::Joined(User& who)
 	}
 
 	if (m_show_nick_list && (m_nicklist != 0)) {
-		unsigned int numusers = 0;
-		if (m_type == CPT_Channel)
-			numusers = GetChannel()->GetNumUsers();
-		else if (m_type == CPT_Server && m_server)
-			numusers = m_server->GetNumUsers();
-		m_usercount_label->SetLabel(wxString::Format(_("%d users"), numusers));
 		m_nicklist->AddUser(who);
+		UpdateUserCountLabel();
 	}
 	// Also add the User to the TextCompletionDatabase
 	textcompletiondatabase.Insert_Mapping(TowxString(who.GetNick()), TowxString(who.GetNick()));
@@ -668,13 +675,8 @@ void ChatPanel::OnChannelJoin(User& who)
 {
 	//    assert( m_type == CPT_Channel || m_type == CPT_Server || m_type == CPT_Battle || m_type == CPT_User );
 	if (m_show_nick_list && (m_nicklist != 0)) {
-		unsigned int numusers = 0;
-		if (m_type == CPT_Channel)
-			numusers = GetChannel()->GetNumUsers();
-		else if (m_type == CPT_Server && m_server)
-			numusers = m_server->GetNumUsers();
-		m_usercount_label->SetLabel(wxString::Format(_("%d users"), numusers));
 		m_nicklist->AddUser(who);
+		UpdateUserCountLabel();
 	}
 	if (m_display_joinitem) {
 		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
@@ -707,13 +709,8 @@ void ChatPanel::Parted(User& who, const wxString& message)
 	} else if (m_type == CPT_Server && me_parted)
 		return;
 	if (m_show_nick_list && (m_nicklist != 0)) {
-		unsigned int numusers = 0;
-		if (m_type == CPT_Channel)
-			numusers = GetChannel()->GetNumUsers();
-		else if (m_type == CPT_Server && m_server)
-			numusers = m_server->GetNumUsers();
-		m_usercount_label->SetLabel(wxString::Format(_("%d users"), numusers));
 		m_nicklist->RemoveUser(who);
+		UpdateUserCountLabel();
 	}
 	// Also remove the User from the TextCompletionDatabase
 	textcompletiondatabase.Delete_Mapping(TowxString(who.GetNick()));
@@ -771,8 +768,9 @@ void ChatPanel::SetChannel(Channel* chan)
 	if ((chan == 0) && (m_channel != 0)) {
 		m_channel->uidata.panel = 0;
 	}
-	if (m_show_nick_list && (m_nicklist != 0)) {
+	if (m_nicklist != 0) {
 		m_nicklist->ClearUsers();
+		UpdateUserCountLabel();
 	}
 
 	if (chan != 0) {
@@ -796,17 +794,18 @@ const IServer* ChatPanel::GetServer() const
 void ChatPanel::SetServer(IServer* serv)
 {
 	ASSERT_LOGIC(m_type == CPT_Server, "Not of type server");
-	if ((serv == 0) && (m_server != 0)) {
-		m_server->uidata.panel = 0;
-		if (m_nicklist) {
-			m_nicklist->StopTimer();
-			m_nicklist->ClearUsers();
-		}
-	} else if (serv != 0) {
+	if (m_nicklist != NULL) {
+		m_nicklist->StopTimer();
+		m_nicklist->ClearUsers();
+		UpdateUserCountLabel();
+	}
+	if (serv != 0) {
 		SetLogFile(_T("server"));
 		serv->uidata.panel = this;
-		if (m_nicklist)
+		if (m_nicklist != NULL)
 			m_nicklist->StartTimer();
+	} else if (m_server != 0) {
+		m_server->uidata.panel = 0;
 	}
 	m_server = serv;
 }
@@ -842,6 +841,7 @@ ChatPanelType ChatPanel::GetPanelType() const
 	return m_type;
 }
 
+
 bool ChatPanel::Say(const wxString& message)
 {
 	static const unsigned int flood_threshold = 5;
@@ -889,7 +889,7 @@ bool ChatPanel::Say(const wxString& message)
 		if (m_type == CPT_Channel) {
 
 			if (m_channel == 0) {
-				OutputLine(_(" You are not in channel or channel does not exist."), sett().GetChatColorError());
+				OutputError(_("You are not in channel or channel does not exist."));
 				return true;
 			}
 			if (line.StartsWith(_T( "/" ))) {
@@ -897,7 +897,7 @@ bool ChatPanel::Say(const wxString& message)
 					return true;
 				if (m_channel->GetServer().ExecuteSayCommand(STD_STRING(line)))
 					return true;
-				OutputLine(wxString::Format(_(" Error: Command (%s) does not exist, use /help for a list of available commands."), line.c_str()), sett().GetChatColorError());
+				OutputError(wxString::Format(_("Command (%s) does not exist, use /help for a list of available commands."), line.c_str()));
 				return true;
 			}
 			m_channel->Say(STD_STRING(line));
@@ -905,7 +905,7 @@ bool ChatPanel::Say(const wxString& message)
 		} else if (m_type == CPT_Battle) {
 
 			if (m_battle == 0) {
-				OutputLine(_(" You are not in battle or battle does not exist, use /help for a list of available commands."), sett().GetChatColorError());
+				OutputError(_("You are not in battle or battle does not exist, use /help for a list of available commands."));
 				return true;
 			}
 			if (line.StartsWith(_T( "/" ))) {
@@ -913,7 +913,7 @@ bool ChatPanel::Say(const wxString& message)
 					return true;
 				if (m_battle->GetServer().ExecuteSayCommand(STD_STRING(line)))
 					return true;
-				OutputLine(wxString::Format(_(" Error: Command (%s) does not exist, use /help for a list of available commands."), line.c_str()), sett().GetChatColorError());
+				OutputError(wxString::Format(_("Command (%s) does not exist, use /help for a list of available commands."), line.c_str()));
 				return true;
 			}
 			m_battle->Say(STD_STRING(line));
@@ -921,7 +921,7 @@ bool ChatPanel::Say(const wxString& message)
 		} else if (m_type == CPT_User) {
 
 			if (m_user == 0) {
-				OutputLine(_(" User is offline."), sett().GetChatColorError());
+				OutputError(_(" User is offline."));
 				return true;
 			}
 			if (line.StartsWith(_T( "/" ))) {
@@ -929,19 +929,21 @@ bool ChatPanel::Say(const wxString& message)
 					return true;
 				if (m_user->GetServer().ExecuteSayCommand(STD_STRING(line)))
 					return true;
-				OutputLine(wxString::Format(_(" Error: Command (%s) does not exist, use /help for a list of available commands."), line.c_str()), sett().GetChatColorError());
+				OutputError(wxString::Format(_("Command (%s) does not exist, use /help for a list of available commands."), line.c_str()));
 				return true;
 			}
 			m_user->Say(STD_STRING(line));
 
 		} else if (m_type == CPT_Server) {
-			if (m_server == 0)
+			if (m_server == 0) {
+				OutputError(_("Not connected to server"));
 				return true;
+			}
 
 			if (line.StartsWith(_T( "/" ))) {
 				if (m_server->ExecuteSayCommand(STD_STRING(line)))
 					return true;
-				OutputLine(wxString::Format(_(" Error: Command (%s) does not exist, use /help for a list of available commands."), line.c_str()), sett().GetChatColorError());
+				OutputError(wxString::Format(_("Command (%s) does not exist, use /help for a list of available commands."), line.c_str()));
 				return true;
 			}
 
@@ -1164,3 +1166,23 @@ void ChatPanel::SetLogFile(const wxString& name)
 		OutputLine(lines[i], sett().GetChatColorServer(), false);
 	}
 }
+
+void ChatPanel::SetVotePanel(VotePanel* votePanel)
+{
+	m_votePanel = votePanel;
+	m_votePanel->SetChatPanel(this);
+}
+
+void ChatPanel::UpdateUserCountLabel()
+{
+	if (m_usercount_label == NULL)
+		return;
+
+	unsigned int numusers = 0;
+	if ((m_type == CPT_Channel) && (GetChannel() != nullptr)) {
+		numusers = GetChannel()->GetNumUsers();
+	} else if ((m_type == CPT_Server) && (m_server != NULL)) {
+		numusers = m_server->GetNumUsers();
+	}
+	m_usercount_label->SetLabel(wxString::Format(_("%d users"), numusers));
+}
