@@ -90,7 +90,6 @@ private:
 	wxMenu* m_menu_all;
 
 	wxMenuItem* displayjoinitem;
-	wxMenuItem* m_autorejoin;
 	wxMenuItem* m_subscribe;
 	wxMenuItem* m_append_menu;
 
@@ -103,7 +102,6 @@ static const long CHAT_MENU_DISABLE_APPEND = wxNewId();
 
 static const long CHAT_MENU_CH_LEAVE = wxNewId();
 static const long CHAT_MENU_CH_DISPLAYJOIN = wxNewId();
-static const long CHAT_MENU_CH_AUTOJOIN = wxNewId();
 static const long CHAT_MENU_CH_SUBSCRIBE = wxNewId();
 
 static const long CHAT_MENU_CH_TOPIC = wxNewId();
@@ -128,7 +126,6 @@ static const long CHAT_MENU_SV_BROADCAST = wxNewId();
 static const long CHAT_MENU_US_CHAT = wxNewId();
 static const long CHAT_MENU_US_JOIN = wxNewId();
 static const long CHAT_MENU_US_SLAP = wxNewId();
-static const long CHAT_MENU_US_ADD_TO_GROUP = wxNewId();
 static const long CHAT_MENU_US_MUTE = wxNewId();
 static const long CHAT_MENU_US_UNMUTE = wxNewId();
 static const long CHAT_MENU_US_KICK = wxNewId();
