@@ -11,23 +11,23 @@ class wxStaticText;
 class wxButton;
 class wxTextCtrl;
 class ContentSearchResultsListctrl;
-class SearchThread;
-
 
 
 class ContentDownloadDialog : public wxDialog, public WindowAttributesPickle
 {
 public:
-	ContentDownloadDialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long int style = wxCAPTION | wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX | wxMINIMIZE_BOX | wxDEFAULT_DIALOG_STYLE , const wxString& name = wxDialogNameStr);
+	ContentDownloadDialog(wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long int style = wxCAPTION | wxRESIZE_BORDER | wxCLOSE_BOX | wxMAXIMIZE_BOX | wxMINIMIZE_BOX | wxDEFAULT_DIALOG_STYLE, const wxString& name = wxDialogNameStr);
 	virtual ~ContentDownloadDialog();
 	virtual bool Show(bool show = true);
-	void OnSearch( wxCommandEvent& event );
-	void OnSearchCompleted( wxCommandEvent& event);
-	void OnDownloadButton( wxCommandEvent& event);
-	void OnCloseButton( wxCommandEvent& event);
-	void OnListDownload( wxListEvent& event );
+	void OnSearch(wxCommandEvent& event);
+	void OnSearchCompleted(wxCommandEvent& event);
+	void OnDownloadButton(wxCommandEvent& event);
+	void OnCloseButton(wxCommandEvent& event);
+	void OnListDownload(wxListEvent& event);
+
 private:
 	DECLARE_EVENT_TABLE()
+	void Search(const wxString& str);
 
 	wxBoxSizer* m_main_sizer;
 	ContentSearchResultsListctrl* m_search_res_w;
@@ -37,8 +37,8 @@ private:
 	wxButton* m_download_button;
 	wxButton* m_close_button;
 
-	SearchThread* m_search_thread;
 	bool wildcardsearch;
+
 public:
 	enum {
 		SEARCH_BUTTON = wxID_HIGHEST,
