@@ -49,7 +49,7 @@ EVT_BUTTON(wxID_ANY, BattleroomMMOptionsTab::OnButton)
 END_EVENT_TABLE()
 
 BattleroomMMOptionsTab::BattleroomMMOptionsTab(IBattle* battle, wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
-    : wxScrolledWindow(parent, id, pos, size, style | wxHSCROLL| wxVSCROLL)
+    : wxScrolledWindow(parent, id, pos, size, style | wxHSCROLL | wxVSCROLL)
     , m_battle(battle)
 {
 	GetAui().manager->AddPane(this, wxLEFT, _T("battleroommmoptionstab"));
@@ -134,7 +134,7 @@ void BattleroomMMOptionsTab::setupOptionsSizer(wxBoxSizer* parent_sizer,
 			parent_sizer->Add(section_sizer, 0, wxALL, section_sizer->GetChildren().size() > 0 ? 5 : 0);
 			num_options++;
 		} else
-			delete section_sizer;
+			wxDELETE(section_sizer);
 	}
 
 	//adds options with no asociated section
@@ -576,25 +576,26 @@ void BattleroomMMOptionsTab::OnInfoButton(wxCommandEvent& event)
 void BattleroomMMOptionsTab::SetBattle(IBattle* battle)
 {
 	m_battle = battle;
+	bool isBattleEnabled = (battle != nullptr);
 
+	m_options_preset_sel->Enable(isBattleEnabled);
+	m_load_btn->Enable(isBattleEnabled);
+	m_save_btn->Enable(isBattleEnabled);
+	m_delete_btn->Enable(isBattleEnabled);
+	m_default_btn->Enable(isBattleEnabled);
 
-	m_options_preset_sel->Enable(m_battle);
-	m_load_btn->Enable(m_battle);
-	m_save_btn->Enable(m_battle);
-	m_delete_btn->Enable(m_battle);
-	m_default_btn->Enable(m_battle);
 	for (chkBoxMap::iterator itor = m_chkbox_map.begin(); itor != m_chkbox_map.end(); ++itor)
-		itor->second->Enable(m_battle);
+		itor->second->Enable(isBattleEnabled);
 	for (comboBoxMap::iterator itor = m_combox_map.begin(); itor != m_combox_map.end(); ++itor)
-		itor->second->Enable(m_battle);
+		itor->second->Enable(isBattleEnabled);
 	for (typename spinCtrlMap::iterator itor = m_spinctrl_map.begin(); itor != m_spinctrl_map.end(); ++itor)
-		itor->second->Enable(m_battle);
+		itor->second->Enable(isBattleEnabled);
 	for (textCtrlMap::iterator itor = m_textctrl_map.begin(); itor != m_textctrl_map.end(); ++itor)
-		itor->second->Enable(m_battle);
+		itor->second->Enable(isBattleEnabled);
 	for (buttonMap::iterator itor = m_button_map.begin(); itor != m_button_map.end(); ++itor)
-		itor->second->Enable(m_battle);
+		itor->second->Enable(isBattleEnabled);
 
-	if (m_battle) {
+	if (isBattleEnabled) {
 		m_options_preset_sel->SetStringSelection(sett().GetModDefaultPresetName(TowxString(m_battle->GetHostModName())));
 		if (!m_battle->IsFounderMe()) {
 			m_options_preset_sel->Disable();
