@@ -40,7 +40,6 @@
 #include "gui/uiutils.h"
 #include "addbotdialog.h"
 #include "iserver.h"
-#include "serverselector.h"
 #include "iconimagelist.h"
 #include "gui/customdialogs.h"
 #include "autobalancedialog.h"
@@ -54,6 +53,7 @@
 #include "log.h"
 #include "utils/lslconversion.h"
 #include "autohostmanager.h"
+#include "votepanel.h"
 
 BEGIN_EVENT_TABLE(BattleRoomTab, wxPanel)
 
@@ -106,7 +106,8 @@ EVT_LIST_ITEM_ACTIVATED(BROOM_OPTIONLIST, BattleRoomTab::OnOptionActivate)
 
 END_EVENT_TABLE()
 
-static wxArrayString CreateIntList(int count) {
+static wxArrayString CreateIntList(int count)
+{
 	wxArrayString res;
 	for (int i = 1; i <= count; ++i) {
 		res.Add(TowxString(i));
@@ -161,8 +162,10 @@ BattleRoomTab::BattleRoomTab(wxWindow* parent, IBattle* battle)
 	m_browse_map_btn = new wxButton(this, BROOM_MAP_BROWSE, _("Map"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
 	//m_browse_map_btn->SetSize( m_browse_map_btn->GetSize().GetWidth() * 2 , m_browse_map_btn->GetSize().GetHeight() ) ; // has 0 effect
 
+	m_votePanel = new VotePanel(this);
 	m_players = new BattleroomListCtrl(m_player_panel, m_battle, false, true);
 	m_chat = new ChatPanel(m_splitter, m_battle);
+	m_chat->SetVotePanel(m_votePanel);
 
 	m_command_line = new wxStaticLine(this, -1, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL);
 
@@ -328,6 +331,7 @@ BattleRoomTab::BattleRoomTab(wxWindow* parent, IBattle* battle)
 	m_top_sizer->Add(m_splitter, 1, wxEXPAND | wxALL, 2);
 	m_top_sizer->Add(m_info_sizer, 0, wxEXPAND | wxALL, 2);
 
+	m_buttons_sizer->Add(m_votePanel);
 	m_buttons_sizer->AddStretchSpacer();
 	m_buttons_sizer->Add(m_host_new_btn, 0, wxEXPAND | wxALL, 2);
 	m_buttons_sizer->AddStretchSpacer();
@@ -386,8 +390,8 @@ void BattleRoomTab::PrintAllySetup()
 {
 	wxString setupstring;
 	if (m_battle) {
-		m_specs_setup_lbl->SetLabel(wxString::Format("%d    ", m_battle->GetSpectators()));
-		m_players_setup_lbl->SetLabel(wxString::Format("%d    ", m_battle->GetNumActivePlayers()));
+		m_specs_setup_lbl->SetLabel(wxString::Format("%d", m_battle->GetSpectators()));
+		m_players_setup_lbl->SetLabel(wxString::Format("%d", m_battle->GetNumActivePlayers()));
 		wxString alliancesstring;
 		int previousalliancesize = 0;
 		bool ffamode = true;
@@ -406,11 +410,11 @@ void BattleRoomTab::PrintAllySetup()
 			//alliancesstring += wxString::Format( _T("(%d)") , itor->first );
 		}
 		if (!ffamode)
-			setupstring += alliancesstring;
+			setupstring += alliancesstring.empty() ? _T("0") : alliancesstring;
 		else
-			setupstring += wxString::Format(_("%d way FFA   "), previousalliancesize);
+			setupstring += wxString::Format(_("%d way FFA"), previousalliancesize);
 	}
-	m_ally_setup_lbl->SetLabel(wxString::Format(_("%s   "), setupstring.c_str()));
+	m_ally_setup_lbl->SetLabel(wxString::Format(_("%s"), setupstring.c_str()));
 	Layout();
 }
 
@@ -690,7 +694,7 @@ void BattleRoomTab::OnAddBot(wxCommandEvent& /*unused*/)
 		bs.aiversion = STD_STRING(dlg.GetAIVersion());
 		bs.aitype = dlg.GetAIType();
 		bs.owner = m_battle->GetMe().GetNick();
-		serverSelector().GetServer().AddBot(m_battle->GetBattleId(), STD_STRING(dlg.GetNick()), bs);
+		m_battle->GetServer().AddBot(m_battle->GetBattleId(), STD_STRING(dlg.GetNick()), bs);
 	}
 }
 
@@ -991,6 +995,7 @@ void BattleRoomTab::OnSavePreset(wxCommandEvent& /*unused*/)
 		return;
 	}
 	m_battle->SaveOptionsPreset(STD_STRING(presetname));
+	UpdatePresetList();
 }
 
 
@@ -1003,6 +1008,7 @@ void BattleRoomTab::OnDeletePreset(wxCommandEvent& /*unused*/)
 	if (result < 0)
 		return;
 	m_battle->DeletePreset(STD_STRING(choices[result]));
+	UpdatePresetList();
 }
 
 void BattleRoomTab::OnSetModDefaultPreset(wxCommandEvent& /*unused*/)
@@ -1114,44 +1120,46 @@ void BattleRoomTab::SortPlayerList()
 void BattleRoomTab::SetBattle(IBattle* battle)
 {
 	m_battle = battle;
+	bool isBattleEnabled = (battle != nullptr);
 
-	m_team_sel->Enable(m_battle);
-	m_ally_sel->Enable(m_battle);
-	m_color_sel->Enable(m_battle);
-	m_side_sel->Enable(m_battle);
-	m_options_preset_sel->Enable(m_battle);
+	m_team_sel->Enable(isBattleEnabled);
+	m_ally_sel->Enable(isBattleEnabled);
+	m_color_sel->Enable(isBattleEnabled);
+	m_side_sel->Enable(isBattleEnabled);
+	m_options_preset_sel->Enable(isBattleEnabled);
 
-	m_minimap->Enable(m_battle);
+	m_minimap->Enable(isBattleEnabled);
 
-	m_player_panel->Enable(m_battle);
+	m_player_panel->Enable(isBattleEnabled);
 
-	m_map_combo->Enable(m_battle);
+	m_map_combo->Enable(isBattleEnabled);
 
-	m_players->Enable(m_battle);
+	m_players->Enable(isBattleEnabled);
 
-	m_leave_btn->Enable(m_battle);
-	m_start_btn->Enable(m_battle);
-	m_addbot_btn->Enable(m_battle);
-	m_manage_players_btn->Enable(m_battle);
-	m_save_btn->Enable(m_battle);
-	m_delete_btn->Enable(m_battle);
-	m_default_btn->Enable(m_battle);
-	m_browse_map_btn->Enable(m_battle);
+	m_leave_btn->Enable(isBattleEnabled);
+	m_start_btn->Enable(isBattleEnabled);
+	m_addbot_btn->Enable(isBattleEnabled);
+	m_manage_players_btn->Enable(isBattleEnabled);
+	m_save_btn->Enable(isBattleEnabled);
+	m_delete_btn->Enable(isBattleEnabled);
+	m_default_btn->Enable(isBattleEnabled);
+	m_browse_map_btn->Enable(isBattleEnabled);
 
-	m_ready_chk->Enable(m_battle);
-	m_spec_chk->Enable(m_battle);
-	m_lock_chk->Enable(m_battle);
-	m_autolock_chk->Enable(m_battle);
+	m_ready_chk->Enable(isBattleEnabled);
+	m_spec_chk->Enable(isBattleEnabled);
+	m_lock_chk->Enable(isBattleEnabled);
+	m_autolock_chk->Enable(isBattleEnabled);
 
-	m_opts_list->Enable(m_battle);
+	m_opts_list->Enable(isBattleEnabled);
 
 	m_minimap->SetBattle(m_battle);
 	m_players->SetBattle(m_battle);
 	m_chat->SetBattle(m_battle);
-
+	m_votePanel->ResetState();
 	m_players->Clear();
 
-	if (m_battle) {
+	if (isBattleEnabled) {
+		m_votePanel->SetCurrentPlayer(&battle->GetMe());
 		RegenerateOptionsList();
 		m_options_preset_sel->SetStringSelection(sett().GetModDefaultPresetName(TowxString(m_battle->GetHostModName())));
 		m_color_sel->SetColor(lslTowxColour(m_battle->GetMe().BattleStatus().colour));
