@@ -37,8 +37,8 @@ public:
 	bool RemoveChatPanel(ChatPanel* panel);
 
 
-	void RejoinChannels();
-	void LeaveChannels();
+	void OnLoggedIn();
+	void OnDisconnected();
 
 	void BroadcastMessage(const wxString& message);
 
