@@ -450,7 +450,7 @@ int MapCtrl::LoadMinimap()
 		return -1;
 	if (m_minimap)
 		return -1;
-	if (!m_battle->MapExists())
+	if (!m_battle->MapExists(false))
 		return -1;
 
 	const std::string map = m_battle->GetHostMapName();
@@ -715,6 +715,22 @@ void MapCtrl::DrawBackground(wxDC& dc)
 		else
 			DrawOutlinedText(dc, _("Download"), 28, height - 50, *wxWHITE, wxColour(50, 50, 50));
 
+		//Draw "%MAPNAME% not found!" label on minimap
+		wxString noMapFoundString = wxString::Format("Map \"%s\" not found!", m_battle->GetHostMapName());
+		const int APPROXIMATE_FONT_SIZE = 6;
+		int labelOrigin = (width / 2) - ((noMapFoundString.Length() / 2) * APPROXIMATE_FONT_SIZE);
+		//If string do not fits to minimap's canvas reduce font size and reformate string
+		if (labelOrigin < 0) {
+			dc.SetFont(wxFont(7, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL));
+
+			const wxString strangeLabel[3] = {"Map", m_battle->GetHostMapName(), "not found!"};
+			for (int labelIndex = 0; labelIndex < 3; labelIndex++) {
+				labelOrigin = (width / 2) - ((strangeLabel[labelIndex].Length() / 2) * (APPROXIMATE_FONT_SIZE - 1));
+				DrawOutlinedText(dc, strangeLabel[labelIndex], labelOrigin, 5 + (labelIndex * APPROXIMATE_FONT_SIZE * 2), wxColour(50, 50, 50), *wxWHITE);
+			}
+		} else {
+			DrawOutlinedText(dc, noMapFoundString, labelOrigin, 10, wxColour(50, 50, 50), *wxWHITE);
+		}
 	} else {
 
 		wxRect r = GetMinimapRect();
@@ -980,7 +996,7 @@ void MapCtrl::DrawUserPositions(wxDC& dc)
 	slLogDebugFunc("");
 	if (m_battle == 0)
 		return;
-	if (!m_battle->MapExists())
+	if (!m_battle->MapExists(false))
 		return;
 
 	wxRect mr = GetMinimapRect();
@@ -1087,7 +1103,7 @@ void MapCtrl::OnMouseMove(wxMouseEvent& event)
 
 	if (longval == IBattle::ST_Pick) {
 
-		if (!m_battle->MapExists())
+		if (!m_battle->MapExists(false))
 			return;
 		if (m_maction == Moved) {
 			User& user = *m_user_expanded;
@@ -1484,7 +1500,7 @@ void MapCtrl::OnRightUp(wxMouseEvent& event)
 							     .getSingleValue("startpostype", LSL::Enum::EngineOption));
 	if (longval == IBattle::ST_Pick) {
 
-		if (!m_battle->MapExists())
+		if (!m_battle->MapExists(false))
 			return;
 
 		if (m_maction != Moved) {
