@@ -33,20 +33,20 @@ TorrentOptionsPanel::TorrentOptionsPanel(wxWindow* parent)
 {
 	GetAui().manager->AddPane(this, wxLEFT, _T("torrentoptionspanel"));
 
-	wxBoxSizer* mainboxsizer = new wxBoxSizer(wxVERTICAL);
+	wxBoxSizer* m_main_sizer = new wxBoxSizer(wxVERTICAL);
 	m_parallel_http = new wxSpinCtrl(this, wxID_ANY, wxString::Format(_T("%d"), sett().GetHTTPMaxParallelDownloads()));
 	m_parallel_http->SetRange(1, 10);
 	m_parallel_http_sizer = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Parallel HTTP Connections when downloading content"));
 	m_parallel_http_sizer->Add(m_parallel_http);
 
 
-	mainboxsizer->Add(m_parallel_http_sizer, 0, wxALL | wxEXPAND, 5);
+	m_main_sizer->Add(m_parallel_http_sizer, 0, wxALL | wxEXPAND, 5);
 
 	//the lazy man's solution to options not being set correctly at panel creation
 	wxCommandEvent dummy;
 	OnRestore(dummy);
 
-	SetSizer(mainboxsizer);
+	SetSizer(m_main_sizer);
 	SetScrollRate(SCROLL_RATE, SCROLL_RATE);
 	Layout();
 }
