@@ -20,6 +20,7 @@
 #include <lslunitsync/unitsync.h>
 
 #include "ui.h"
+#include "offlineserver.h"
 #include "tasserver.h"
 #include "utils/slconfig.h"
 #include "iserver.h"
@@ -87,6 +88,7 @@ Ui::Ui()
 	m_main_win = new MainWindow();
 	CustomMessageBoxBase::setLobbypointer(m_main_win);
 	m_serv = new TASServer();
+//	m_serv = new OfflineServer();
 	serverSelector().SetCurrentServer(m_serv);
 	ConnectGlobalEvent(this, GlobalEvent::OnSpringTerminated, wxObjectEventFunction(&Ui::OnSpringTerminated));
 	ConnectGlobalEvent(this, GlobalEvent::OnQuit, wxObjectEventFunction(&Ui::OnQuit));
@@ -155,7 +157,6 @@ void Ui::ShowConnectWindow()
 
 //! @brief Connects to default server or opens the ConnectWindow
 //!
-//! @todo Fix Auto Connect
 //! @see DoConnect
 void Ui::Connect()
 {
@@ -177,8 +178,9 @@ void Ui::Connect()
 
 void Ui::Reconnect()
 {
-	if (s_reconnect_delay_ms <= s_max_reconnect_delay) {
-		s_reconnect_delay_ms += std::max<unsigned int>(s_max_reconnect_delay * 0.50, 1000);
+	if (s_reconnect_delay_ms <= s_max_reconnect_delay) { //increase reconnect delay each time we try to reconnect
+		s_reconnect_delay_ms += std::max<unsigned int>(s_reconnect_delay_ms * 0.50, 1000);
+		wxLogDebug("changed reconnect delay to %d", s_reconnect_delay_ms / 1000);
 	}
 	const wxString servname = sett().GetDefaultServer();
 	const wxString pass = sett().GetServerAccountPass(servname);
@@ -186,7 +188,6 @@ void Ui::Reconnect()
 		ShowConnectWindow();
 		return;
 	}
-	Disconnect();
 	DoConnect(servname, sett().GetServerAccountNick(servname), pass);
 }
 
@@ -288,7 +289,9 @@ void Ui::Quit()
 void Ui::Download(const std::string& category, const std::string& name, const std::string& /*hash */)
 {
 	int count = prDownloader().GetDownload(category, name);
-	assert(count > 0);
+	if (count < 1) {
+		wxLogError(_("prDownloader failed to create thread!"));
+	}
 }
 
 //! @brief Display a dialog asking a question with OK and Canel buttons
@@ -524,7 +527,7 @@ void Ui::OnLoggedIn()
 {
 	if (m_main_win == 0)
 		return;
-	mw().GetChatTab().RejoinChannels();
+	mw().GetChatTab().OnLoggedIn();
 	mw().GetBattleListTab().SortBattleList();
 }
 
@@ -542,10 +545,9 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 		return;
 	}
 
-	mw().GetJoinTab().LeaveCurrentBattle();
-	mw().GetBattleListTab().RemoveAllBattles();
-
-	mw().GetChatTab().LeaveChannels();
+	mw().GetJoinTab().OnDisconnected();
+	mw().GetBattleListTab().OnDisconnected();
+	mw().GetChatTab().OnDisconnected();
 
 	const wxString disconnect_msg = wxString::Format(_("disconnected from server: %s"), server.GetServerName().c_str());
 	UiEvents::GetStatusEventSender(UiEvents::addStatusMessage).SendEvent(UiEvents::StatusData(disconnect_msg, 1));
@@ -1041,7 +1043,7 @@ void Ui::FirstRunWelcome()
 bool Ui::StartUpdate(const std::string& latestVersion)
 {
 	const wxString updatedir = TowxString(SlPaths::GetUpdateDir());
-	const int mindirlen = 9; // safety, minimal is/should be: C:\update
+	const size_t mindirlen = 9; // safety, minimal is/should be: C:\update
 	if ((updatedir.size() <= mindirlen)) {
 		wxLogError(_T("Invalid update dir: ") + updatedir);
 		return false;
