@@ -71,13 +71,6 @@ private:
 	UNITSYNC_EXCEPTION( m_loaded, "Unitsync function not loaded:" #arg ); \
 	CHECK_FUNCTION( arg );
 
-// convert const char* to std::string, as std::string(NULL) crashes
-inline std::string SafeString(const char* str)
-{
-	if (str == NULL) return "";
-	return std::string(str);
-}
-
 
 namespace LSL {
 
@@ -283,7 +276,7 @@ int UnitsyncLib::GetModIndex( const std::string& name )
 std::string UnitsyncLib::GetSpringVersion()
 {
 	InitLib( m_get_spring_version );
-	std::string version = SafeString(m_get_spring_version());
+	std::string version = Util::SafeString(m_get_spring_version());
 	if (m_is_spring_release_version && m_get_spring_version_patchset && m_is_spring_release_version()) {
 		version += ".";
 		version += m_get_spring_version_patchset();
@@ -294,7 +287,7 @@ std::string UnitsyncLib::GetSpringVersion()
 std::string UnitsyncLib::GetSpringDataDir()
 {
 	InitLib( m_get_writeable_data_dir );
-	return SafeString(m_get_writeable_data_dir());
+	return Util::SafeString(m_get_writeable_data_dir());
 }
 
 int UnitsyncLib::GetSpringDataDirCount()
@@ -306,13 +299,13 @@ int UnitsyncLib::GetSpringDataDirCount()
 std::string UnitsyncLib::GetSpringDataDirByIndex( const int index )
 {
 	InitLib( m_get_data_dir_by_index );
-	return SafeString(m_get_data_dir_by_index( index ));
+	return Util::SafeString(m_get_data_dir_by_index( index ));
 }
 
 std::string UnitsyncLib::GetConfigFilePath()
 {
 	InitLib( m_get_spring_config_file_path );
-	return SafeString(m_get_spring_config_file_path());
+	return Util::SafeString(m_get_spring_config_file_path());
 }
 
 int UnitsyncLib::GetMapCount()
@@ -321,16 +314,16 @@ int UnitsyncLib::GetMapCount()
 	return m_get_map_count();
 }
 
-std::string UnitsyncLib::GetMapChecksum( int index )
+unsigned int UnitsyncLib::GetMapChecksum( int index )
 {
 	InitLib( m_get_map_checksum );
-	return Util::ToString( (unsigned int)m_get_map_checksum( index ) );
+	return m_get_map_checksum( index );
 }
 
 std::string UnitsyncLib::GetMapName( int index )
 {
 	InitLib( m_get_map_name );
-	return SafeString(m_get_map_name( index ));
+	return Util::SafeString(m_get_map_name( index ));
 }
 
 int UnitsyncLib::GetMapArchiveCount( int index )
@@ -342,7 +335,7 @@ int UnitsyncLib::GetMapArchiveCount( int index )
 std::string UnitsyncLib::GetMapArchiveName( int arnr )
 {
 	InitLib( m_get_map_archive_name );
-	return SafeString(m_get_map_archive_name( arnr ));
+	return Util::SafeString(m_get_map_archive_name( arnr ));
 }
 
 UnitsyncLib::StringVector UnitsyncLib::GetMapDeps( int index )
@@ -362,7 +355,7 @@ MapInfo UnitsyncLib::GetMapInfoEx( int index, int version )
 		// old fetch method
 		InitLib( m_get_map_info_ex );
 
-		const std::string mapName =  SafeString(m_get_map_name( index ));
+		const std::string mapName =  Util::SafeString(m_get_map_name( index ));
 
 		char tmpdesc[256];
 		char tmpauth[256];
@@ -382,7 +375,7 @@ MapInfo UnitsyncLib::GetMapInfoEx( int index, int version )
 		InitLib( m_get_map_description )
 
 		MapInfo info;
-		info.description = SafeString(m_get_map_description( index));
+		info.description = Util::SafeString(m_get_map_description( index));
 		info.tidalStrength = m_get_map_tidalStrength(index);
 		info.gravity = m_get_map_gravity(index);
 
@@ -464,10 +457,10 @@ UnitsyncImage UnitsyncLib::GetHeightmap( const std::string& mapFileName )
 	return img;
 }
 
-std::string UnitsyncLib::GetPrimaryModChecksum( int index )
+unsigned int UnitsyncLib::GetPrimaryModChecksum( int index )
 {
 	InitLib( m_get_mod_checksum );
-	return Util::ToString( (unsigned int)m_get_mod_checksum( index ) );
+	return m_get_mod_checksum( index );
 }
 
 int UnitsyncLib::GetPrimaryModIndex( const std::string& modName )
@@ -479,7 +472,7 @@ int UnitsyncLib::GetPrimaryModIndex( const std::string& modName )
 std::string UnitsyncLib::GetPrimaryModName( int index )
 {
 	InitLib( m_get_mod_name );
-	return SafeString(m_get_mod_name( index ));
+	return Util::SafeString(m_get_mod_name( index ));
 }
 
 int UnitsyncLib::GetPrimaryModCount()
@@ -495,31 +488,31 @@ std::string UnitsyncLib::GetPrimaryModArchive( int index )
 	int count = m_get_mod_count();
 	if (index >= count)
 		LSL_THROW( unitsync, "index out of bounds");
-	return SafeString(m_get_mod_archive( index ));
+	return Util::SafeString(m_get_mod_archive( index ));
 }
 
 std::string UnitsyncLib::GetPrimaryModShortName( int index )
 {
 	InitLib( m_get_primary_mod_short_name );
-	return SafeString(m_get_primary_mod_short_name( index ));
+	return Util::SafeString(m_get_primary_mod_short_name( index ));
 }
 
 std::string UnitsyncLib::GetPrimaryModVersion( int index )
 {
 	InitLib( m_get_primary_mod_version );
-	return SafeString(m_get_primary_mod_version( index ));
+	return Util::SafeString(m_get_primary_mod_version( index ));
 }
 
 std::string UnitsyncLib::GetPrimaryModMutator( int index )
 {
 	InitLib( m_get_primary_mod_mutator );
-	return SafeString(m_get_primary_mod_mutator( index ));
+	return Util::SafeString(m_get_primary_mod_mutator( index ));
 }
 
 std::string UnitsyncLib::GetPrimaryModGame( int index )
 {
 	InitLib( m_get_primary_mod_game );
-	return SafeString(m_get_primary_mod_game( index ));
+	return Util::SafeString(m_get_primary_mod_game( index ));
 }
 
 std::string UnitsyncLib::GetPrimaryModShortGame( int index )
@@ -531,7 +524,7 @@ std::string UnitsyncLib::GetPrimaryModShortGame( int index )
 std::string UnitsyncLib::GetPrimaryModDescription( int index )
 {
 	InitLib( m_get_primary_mod_description );
-	return SafeString(m_get_primary_mod_description( index ));
+	return Util::SafeString(m_get_primary_mod_description( index ));
 }
 
 int UnitsyncLib::GetPrimaryModArchiveCount( int index )
@@ -543,13 +536,13 @@ int UnitsyncLib::GetPrimaryModArchiveCount( int index )
 std::string UnitsyncLib::GetPrimaryModArchiveList( int arnr )
 {
 	InitLib( m_get_primary_mod_archive_list );
-	return SafeString(m_get_primary_mod_archive_list( arnr ));
+	return Util::SafeString(m_get_primary_mod_archive_list( arnr ));
 }
 
-std::string UnitsyncLib::GetPrimaryModChecksumFromName( const std::string& name )
+unsigned int UnitsyncLib::GetPrimaryModChecksumFromName( const std::string& name )
 {
 	InitLib( m_get_primary_mod_checksum_from_name );
-	return Util::ToString( (unsigned int)m_get_primary_mod_checksum_from_name( name.c_str() ) );
+	return m_get_primary_mod_checksum_from_name( name.c_str() );
 }
 
 UnitsyncLib::StringVector UnitsyncLib::GetModDeps( int index )
@@ -589,13 +582,13 @@ void UnitsyncLib::AddArchive(const std::string &name)
 std::string UnitsyncLib::GetFullUnitName( int index )
 {
 	InitLib( m_get_unit_full_name );
-	return SafeString(m_get_unit_full_name( index ));
+	return Util::SafeString(m_get_unit_full_name( index ));
 }
 
 std::string UnitsyncLib::GetUnitName( int index )
 {
 	InitLib( m_get_unit_name );
-	return SafeString(m_get_unit_name( index ));
+	return Util::SafeString(m_get_unit_name( index ));
 }
 
 int UnitsyncLib::GetUnitCount()
@@ -664,7 +657,7 @@ unsigned int UnitsyncLib::GetValidMapCount( const std::string& modname )
 std::string UnitsyncLib::GetValidMapName( unsigned int MapIndex )
 {
 	InitLib( m_get_valid_map );
-	return SafeString(m_get_valid_map( MapIndex ));
+	return Util::SafeString(m_get_valid_map( MapIndex ));
 }
 
 int UnitsyncLib::GetMapOptionCount( const std::string& name )
@@ -707,31 +700,31 @@ int UnitsyncLib::GetAIOptionCount( const std::string& modname, int aiIndex )
 std::string UnitsyncLib::GetOptionKey( int optIndex )
 {
 	InitLib( m_get_option_key );
-	return SafeString(m_get_option_key( optIndex ));
+	return Util::SafeString(m_get_option_key( optIndex ));
 }
 
 std::string UnitsyncLib::GetOptionName( int optIndex )
 {
 	InitLib( m_get_option_name );
-	return SafeString(m_get_option_name( optIndex ));
+	return Util::SafeString(m_get_option_name( optIndex ));
 }
 
 std::string UnitsyncLib::GetOptionDesc( int optIndex )
 {
 	InitLib( m_get_option_desc );
-	return SafeString(m_get_option_desc( optIndex ));
+	return Util::SafeString(m_get_option_desc( optIndex ));
 }
 
 std::string UnitsyncLib::GetOptionSection( int optIndex )
 {
 	InitLib( m_get_option_section );
-	return SafeString(m_get_option_section( optIndex ));
+	return Util::SafeString(m_get_option_section( optIndex ));
 }
 
 std::string UnitsyncLib::GetOptionStyle( int optIndex )
 {
 	InitLib( m_get_option_style );
-	return SafeString(m_get_option_style( optIndex ));
+	return Util::SafeString(m_get_option_style( optIndex ));
 }
 
 int UnitsyncLib::GetOptionType( int optIndex )
@@ -773,7 +766,7 @@ float UnitsyncLib::GetOptionNumberStep( int optIndex )
 std::string UnitsyncLib::GetOptionStringDef( int optIndex )
 {
 	InitLib( m_get_option_string_def );
-	return SafeString(m_get_option_string_def( optIndex ));
+	return Util::SafeString(m_get_option_string_def( optIndex ));
 }
 
 int UnitsyncLib::GetOptionStringMaxLen( int optIndex )
@@ -791,25 +784,25 @@ int UnitsyncLib::GetOptionListCount( int optIndex )
 std::string UnitsyncLib::GetOptionListDef( int optIndex )
 {
 	InitLib( m_get_option_list_def );
-	return SafeString(m_get_option_list_def( optIndex ));
+	return Util::SafeString(m_get_option_list_def( optIndex ));
 }
 
 std::string UnitsyncLib::GetOptionListItemKey( int optIndex, int itemIndex )
 {
 	InitLib( m_get_option_list_item_key );
-	return SafeString(m_get_option_list_item_key( optIndex, itemIndex  ));
+	return Util::SafeString(m_get_option_list_item_key( optIndex, itemIndex  ));
 }
 
 std::string UnitsyncLib::GetOptionListItemName( int optIndex, int itemIndex )
 {
 	InitLib( m_get_option_list_item_name );
-	return SafeString(m_get_option_list_item_name( optIndex, itemIndex  ));
+	return Util::SafeString(m_get_option_list_item_name( optIndex, itemIndex  ));
 }
 
 std::string UnitsyncLib::GetOptionListItemDesc( int optIndex, int itemIndex )
 {
 	InitLib( m_get_option_list_item_desc );
-	return SafeString(m_get_option_list_item_desc( optIndex, itemIndex  ));
+	return Util::SafeString(m_get_option_list_item_desc( optIndex, itemIndex  ));
 }
 
 int UnitsyncLib::OpenArchive( const std::string& name )
@@ -862,7 +855,7 @@ int UnitsyncLib::SizeArchiveFile( int archive, int handle )
 std::string UnitsyncLib::GetArchivePath( const std::string& name )
 {
 	InitLib( m_get_archive_path );
-	return SafeString(m_get_archive_path( name.c_str() ));
+	return Util::SafeString(m_get_archive_path( name.c_str() ));
 }
 
 int UnitsyncLib::GetSpringConfigInt( const std::string& key, int defValue )
@@ -874,7 +867,7 @@ int UnitsyncLib::GetSpringConfigInt( const std::string& key, int defValue )
 std::string UnitsyncLib::GetSpringConfigString( const std::string& key, const std::string& defValue )
 {
 	InitLib( m_get_spring_config_string );
-	return SafeString(m_get_spring_config_string( key.c_str(), defValue.c_str() ));
+	return Util::SafeString(m_get_spring_config_string( key.c_str(), defValue.c_str() ));
 }
 
 float UnitsyncLib::GetSpringConfigFloat( const std::string& key, const float defValue )
@@ -914,9 +907,9 @@ UnitsyncLib::StringVector UnitsyncLib::GetAIInfo( int aiIndex )
 {
 	InitLib( m_get_skirmish_ai_count );
 	CHECK_FUNCTION( m_get_skirmish_ai_info_count );
-	CHECK_FUNCTION( m_get_skirmish_ai_info_description );
-	CHECK_FUNCTION( m_get_skirmish_ai_info_key );
-	CHECK_FUNCTION( m_get_skirmish_ai_info_value );
+	CHECK_FUNCTION( m_get_description );
+	CHECK_FUNCTION( m_get_info_key );
+	CHECK_FUNCTION( m_get_info_value );
 
 	StringVector ret;
 	if ( !(( aiIndex >= 0 ) && ( aiIndex < m_get_skirmish_ai_count() )) )
@@ -925,17 +918,17 @@ UnitsyncLib::StringVector UnitsyncLib::GetAIInfo( int aiIndex )
 	int infoCount = m_get_skirmish_ai_info_count( aiIndex );
 	for( int i = 0; i < infoCount; i++ )
 	{
-		ret.push_back( m_get_skirmish_ai_info_key( i ) );
-		ret.push_back( m_get_skirmish_ai_info_value( i ) );
-		ret.push_back( m_get_skirmish_ai_info_description( i ) );
+		ret.push_back( m_get_info_key( i ) );
+		ret.push_back( m_get_info_value( i ) );
+		ret.push_back( m_get_description( i ) );
 	}
 	return ret;
 }
 
-std::string UnitsyncLib::GetArchiveChecksum( const std::string& VFSPath )
+unsigned int UnitsyncLib::GetArchiveChecksum( const std::string& VFSPath )
 {
 	InitLib( m_get_archive_checksum );
-	return Util::ToString( m_get_archive_checksum( VFSPath.c_str() ) );
+	return m_get_archive_checksum( VFSPath.c_str() );
 }
 
 /// lua parser
@@ -967,7 +960,7 @@ bool UnitsyncLib::ParserExecute()
 std::string UnitsyncLib::ParserErrorLog()
 {
 	InitLib( m_parser_error_log );
-	return SafeString(m_parser_error_log());
+	return Util::SafeString(m_parser_error_log());
 }
 
 void UnitsyncLib::ParserAddTable( int key, bool override )
@@ -1135,7 +1128,7 @@ bool UnitsyncLib::GetKeyValue( int key, bool defval )
 std::string UnitsyncLib::GetKeyValue( int key, const std::string& defval )
 {
 	InitLib( m_parser_int_key_get_string_value );
-	return SafeString(m_parser_int_key_get_string_value( key, defval.c_str() ));
+	return Util::SafeString(m_parser_int_key_get_string_value( key, defval.c_str() ));
 }
 
 float UnitsyncLib::GetKeyValue( int key, float defval )
@@ -1159,7 +1152,7 @@ bool UnitsyncLib::GetKeyValue( const std::string& key, bool defval )
 std::string UnitsyncLib::GetKeyValue( const std::string& key, const std::string& defval )
 {
 	InitLib( m_parser_string_key_get_string_value );
-	return SafeString(m_parser_string_key_get_string_value( key.c_str(), defval.c_str() ));
+	return Util::SafeString(m_parser_string_key_get_string_value( key.c_str(), defval.c_str() ));
 }
 
 float UnitsyncLib::GetKeyValue( const std::string& key, float defval )
@@ -1168,6 +1161,49 @@ float UnitsyncLib::GetKeyValue( const std::string& key, float defval )
 	return m_parser_string_key_get_float_value( key.c_str(), defval );
 }
 
+int UnitsyncLib::GetPrimaryModInfoCount(int index)
+{
+	InitLib( m_get_primary_mod_info_count );
+	return m_get_primary_mod_info_count(index);
+}
+
+const char* UnitsyncLib::GetInfoKey(int index)
+{
+	InitLib( m_get_info_key );
+	return m_get_info_key(index);
+}
+
+const char* UnitsyncLib::GetInfoType(int index)
+{
+	InitLib( m_get_info_type );
+	return m_get_info_type(index);
+}
+
+const char* UnitsyncLib::GetInfoValueString(int index)
+{
+	InitLib( m_get_info_value_string );
+	return m_get_info_value_string(index);
+}
+
+int UnitsyncLib::GetInfoValueInteger(int index)
+{
+	InitLib( m_get_info_value_integer );
+	return m_get_info_value_integer(index);
+}
+
+float UnitsyncLib::GetInfoValueFloat(int index)
+{
+	InitLib( m_get_info_value_float );
+	return m_get_info_value_float(index);
+}
+
+bool UnitsyncLib::GetInfoValueBool(int index)
+{
+	InitLib( m_get_info_value_bool );
+	return m_get_info_value_bool(index);
+}
+
+
 UnitsyncLib& susynclib()
 {
 	static LSL::Util::LineInfo<UnitsyncLib> m( AT );
