@@ -1,7 +1,7 @@
 #ifndef LSL_IMAGE_H
 #define LSL_IMAGE_H
 
-#include <boost/shared_ptr.hpp>
+#include <string>
 
 //we really, really don't want to include the cimg
 // header here, it's 2.1MB of template magic :)
@@ -28,12 +28,8 @@ class uninitialized_array;
 class UnitsyncImage
 {
 private:
-    typedef unsigned short
-        RawDataType;
-    typedef cimg_library::CImg<RawDataType>
-        PrivateImageType;
-	typedef boost::shared_ptr<PrivateImageType>
-		PrivateImagePtrType;
+	typedef unsigned short RawDataType;
+	typedef cimg_library::CImg<RawDataType> PrivateImageType;
 public:
 	UnitsyncImage();
 	UnitsyncImage& operator= (const UnitsyncImage& other);
@@ -69,9 +65,9 @@ public:
 	// makes given color transparent
 	void MakeTransparent(unsigned short r = 255, unsigned short g = 255, unsigned short b = 255);
 private:
-	UnitsyncImage( PrivateImagePtrType ptr );
+	UnitsyncImage( PrivateImageType* ptr );
 	static PrivateImageType* NewImagePtr( int width = 0, int height = 0 );
-	PrivateImagePtrType m_data_ptr;
+	PrivateImageType* m_data_ptr;
 };
 
 } //namespace LSL
