@@ -145,12 +145,14 @@ void Socket::OnSocketEvent(wxSocketEvent& event)
 			break;
 		case wxSOCKET_LOST:
 			m_net_class.OnDisconnected();
+			m_sock.Close();
 			break;
 		case wxSOCKET_CONNECTION:
 			m_net_class.OnConnected();
 			break;
 		default:
 			m_net_class.OnError("Unknown socket event.");
+			m_sock.Close();
 			break;
 	}
 }
@@ -212,10 +214,12 @@ void Socket::SetTimeout(const int seconds)
 //! @brief Disconnect from remote host if connected.
 void Socket::Disconnect()
 {
+	const bool wasconnected = m_sock.IsConnected();
 	m_buffer.clear();
-
-	m_sock.Notify(false);
-	m_net_class.OnDisconnected();
+	m_sock.Close();
+	if (wasconnected) { //.Close() disables all events, fire it manually (as last to prevent recursions loops)
+		m_net_class.OnDisconnected();
+	}
 }
 
 
@@ -298,8 +302,10 @@ wxString Socket::Receive()
 
 	do {
 		m_sock.Read(buf, chunk_size);
-		const int readnum = m_sock.LastCount();
-		ret += convert(buf, readnum);
+		readnum = m_sock.LastCount();
+		if (readnum > 0) {
+			ret += convert(buf, readnum);
+		}
 	} while (readnum > 0);
 
 	return ret;
@@ -330,15 +336,15 @@ SockError Socket::Error() const
 
 
 //! @brief used to retrieve local ip address behind NAT to communicate to the server on login
-wxString Socket::GetLocalAddress() const
+std::string Socket::GetLocalAddress() const
 {
 	if (!m_sock.IsConnected())
-		return wxEmptyString;
+		return "";
 
 	wxIPV4address localaddr;
 	m_sock.GetLocal(localaddr);
 
-	return localaddr.IPAddress();
+	return STD_STRING(localaddr.IPAddress());
 }
 
 
