@@ -953,7 +953,7 @@ void TASServer::RelayCmd(const std::string& command, const std::string& param)
 	}
 	wxString msg = _T("!") + TowxString(command).Lower(); // prefix commands with !
 	if (!param.empty()) {
-		msg += + _T(" ") + TowxString(param);
+		msg += _T(" ") + TowxString(param);
 	}
 	SayPrivate(m_relay_host_bot, STD_STRING(msg));
 }
@@ -1338,11 +1338,10 @@ void TASServer::SendHostInfo(HostInfo update)
 
 	if ((update & (IBattle::HI_Map | IBattle::HI_Locked | IBattle::HI_Spectators)) > 0) {
 		// UPDATEBATTLEINFO Spectatorsize locked maphash {mapname}
-		wxString cmd = wxString::Format(_T("%d %d "), battle.GetSpectators(), battle.IsLocked());
-		cmd += TowxString(LSL::Util::MakeHashSigned(battle.LoadMap().hash) + " ");
-		cmd += TowxString(battle.LoadMap().name);
+		std::string cmd = stdprintf("%d %d %s %s", battle.GetSpectators(), battle.IsLocked(),
+				LSL::Util::MakeHashSigned(battle.LoadMap().hash).c_str(), battle.LoadMap().name.c_str());
 
-		SendCmd("UPDATEBATTLEINFO", STD_STRING(cmd), battle.IsProxy());
+		SendCmd("UPDATEBATTLEINFO", cmd, battle.IsProxy());
 	}
 	if ((update & IBattle::HI_Send_All_opts) > 0) {
 		std::string cmd;
@@ -1992,19 +1991,19 @@ IBattle::GameType IntToGameType(int gt)
 }
 
 // send script.txt to relayhost
-void TASServer::SendScriptToProxy( const std::string& script )
+void TASServer::SendScriptToProxy(const std::string& script)
 {
 	LSL::StringVector strings = LSL::Util::StringTokenize(script, "\n");
 	int relaylenghtprefix = 10 + 1 + m_relay_host_bot.length() + 2; // SAYPRIVATE + space + botname + space + exclamation mark lenght
 	int lenght = script.size();
-	lenght += relaylenghtprefix + 11 + 1; // CLEANSCRIPT command size
-	lenght += strings.size() * ( relaylenghtprefix + 16 + 1 ); // num lines * APPENDSCRIPTLINE + space command size ( \n is already counted in script.size)
-	lenght += relaylenghtprefix + 9 + 1; // STARTGAME command size
-	const int time = lenght / m_sock->GetSendRateLimit(); // calculate time in seconds to upload script
-	DoActionBattle( m_battle_id, stdprintf("is preparing to start the game, game will start in approximately %d seconds",time));
+	lenght += relaylenghtprefix + 11 + 1;			 // CLEANSCRIPT command size
+	lenght += strings.size() * (relaylenghtprefix + 16 + 1); // num lines * APPENDSCRIPTLINE + space command size ( \n is already counted in script.size)
+	lenght += relaylenghtprefix + 9 + 1;			 // STARTGAME command size
+	const int time = lenght / m_sock->GetSendRateLimit();    // calculate time in seconds to upload script
+	DoActionBattle(m_battle_id, stdprintf("is preparing to start the game, game will start in approximately %d seconds", time));
 	RelayCmd("CLEANSCRIPT");
 
-	for (const std::string& line: strings) {
+	for (const std::string& line : strings) {
 		RelayCmd("APPENDSCRIPTLINE", line);
 	}
 	RelayCmd("STARTGAME");
