@@ -22,35 +22,36 @@ class User;
 
 class UserList
 {
-  public:
-      //! @brief mapping from nick to user object
-    typedef std::map<std::string, User*> user_map_t;
-    //! @brief iterator for user map
-    typedef user_map_t::iterator user_iter_t;
-    typedef user_map_t::const_iterator user_const_iter_t;
+public:
+	//! @brief mapping from nick to user object
+	typedef std::map<std::string, User*> user_map_t;
+	//! @brief iterator for user map
+	typedef user_map_t::iterator user_iter_t;
+	typedef user_map_t::const_iterator user_const_iter_t;
 
-    UserList();
-    virtual ~UserList() {}
-    void AddUser( User& user );
-    void RemoveUser( std::string const& nick );
-    User& GetUser( std::string const& nick ) const;
-    User& GetUser( user_map_t::size_type index ) const;
-    bool UserExists( std::string const& nick ) const;
-    user_map_t::size_type GetNumUsers() const;
+	UserList();
+	virtual ~UserList()
+	{
+	}
+	void AddUser(User& user);
+	void RemoveUser(std::string const& nick);
+	User& GetUser(std::string const& nick) const;
+	User& GetUser(user_map_t::size_type index) const;
+	bool UserExists(std::string const& nick) const;
+	user_map_t::size_type GetNumUsers() const;
 
-    void Nullify();
-/*
+	void Nullify();
+	/*
 	UserList& operator= (const UserList& other) = delete;
 	UserList& operator= (const UserList&& other);
 */
 protected:
-    user_map_t m_users;
+	user_map_t m_users;
+
 private:
 	// The following are used as internal cache to speed up random access:
-    mutable user_const_iter_t m_seek;
-    mutable user_map_t::size_type m_seekpos;
-
+	mutable user_const_iter_t m_seek;
+	mutable user_map_t::size_type m_seekpos;
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_USERLIST_H
-
