@@ -3,9 +3,6 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_PLATFORM_H
 #define SPRINGLOBBY_HEADERGUARD_PLATFORM_H
 
-class wxWindow;
-class wxString;
-
 #include <wx/string.h>
 #include <wx/arrstr.h>
 
@@ -14,13 +11,15 @@ class wxString;
     this will copy dir (and everything below that recursively to /some/other/path/dir
     \return true if successful
 */
-bool MoveDirWithFilebackupRename( wxString from, wxString to, bool backup = true, bool silent = false);
+bool MoveDirWithFilebackupRename(wxString from, wxString to, bool backup = true, bool silent = false);
 
 //! set new cwd in ctor, reset to old in dtor
-class CwdGuard {
+class CwdGuard
+{
 public:
-	CwdGuard( const wxString& new_cwd );
+	CwdGuard(const wxString& new_cwd);
 	~CwdGuard();
+
 private:
 	wxString m_old_cwd;
 };
@@ -29,6 +28,7 @@ int RunProcess(const wxString& cmd, const wxArrayString& params, const bool asyn
 int BrowseFolder(const wxString& path);
 int WaitForExit(int pid);
 void ErrorMsgBox(const wxString& err, bool silent = false);
+bool SafeMkdir(const wxString& dir);
 
 //!
 
